#!/bin/bash

function get_folders {
    local INDECES=()
    for folder in $(ls -d */); do
        INDECES+="$folder "
    done
    INDECES+=". "
    echo "$INDECES"
}

function gen_index {
    IDX_NAME=$1
    BASE=$2
    > $IDX_NAME
    if [ x"$3" != x ]; then
        echo -e "/*$3*/" > $IDX_NAME
    fi
    OS=$(uname)
    if [ x"$BASE" == x"." ]; then
        if [ $OS == "Darwin" ]; then
            find -E $BASE -regex ".*\.yara?" | grep -vE "_?index.yara?" | awk '{print "include \"" $0 "\""}' >> $IDX_NAME
        else
            # Linux version and potentialy Cygwin
            find $BASE -regex ".*\.yara?" | grep -vE "_?index.yara?" | awk '{print "include \"" $0 "\""}' >> $IDX_NAME
        fi
    else
        if [ $OS == "Darwin" ]; then
            find -E $BASE -regex ".*\.yara?" | grep -vE "_?index.yara?" | awk '{print "include \"./" $0 "\""}' >> $IDX_NAME
        else
            # Linux version and potentialy Cygwin
            find $BASE -regex ".*\.yara?" | grep -vE "_?index.yara?" | awk '{print "include \"./" $0 "\""}' >> $IDX_NAME
        fi
    fi
}

## Main

echo "   **************************"
echo "          Yara-Rules"
echo "        Index generator"
echo "   **************************"

for folder in $(get_folders)
do
    if [ x"$folder" == x"." ]; then
        BASE="."
        IDX_NAME="index.yar"
        echo "[+] Generating index..."
    else
        BASE=$(echo $folder | rev | cut -c 2- | rev)
        IDX_NAME="$BASE"_index.yar
        echo "[+] Generating $BASE index..."
    fi
    gen_index $IDX_NAME $BASE "\nGenerated by Yara-Rules\nOn $(date +%d-%m-%Y)\n"
done
